pub struct Metadata<'s> {
pub source: &'s str,
pub source_path: &'s str,
pub term_width: Option<usize>,
pub ansi: bool,
pub unicode: bool,
pub anonymized_line_numbers: bool,
}Fields
source: &'s strThe source code
source_path: &'s strThe path to the source code
term_width: Option<usize>When Some, the specified width is used as the terminal width. If None, a reasonable default value is used.
ansi: boolWhen true, ansi escape codes are used to add color and OSC8 url links
unicode: boolWhen true, unicode styling is used. When false everything is plain ascii
anonymized_line_numbers: boolWhen true, the line numbers will not be shown. This can be great for UI tests